@@ -30,49 +30,49 @@
 #define COMPOSITE 1
 
 /* Build DPMS extension */
-#define DPMSExtension
+#define DPMSExtension 1
 
 /* Build DRI3 extension */
 #undef DRI3
 
 /* Build GLX extension */
-#define GLXEXT
+#define GLXEXT 1
 
 /* Support XDM-AUTH*-1 */
-#define HASXDMAUTH
+#define HASXDMAUTH 1
 
 /* Support SHM */
-#define HAS_SHM
+#define HAS_SHM 1
 
 /* Define to 1 if you have the `reallocarray' function. */
-#define HAVE_REALLOCARRAY
+#define HAVE_REALLOCARRAY 1
 
 /* Define to 1 if you have the `strcasecmp' function. */
-#define HAVE_STRCASECMP
+#define HAVE_STRCASECMP 1
 
 /* Define to 1 if you have the `strcasestr' function. */
-#define HAVE_STRCASESTR
+#define HAVE_STRCASESTR 1
 
 /* Define to 1 if you have the `strlcat' function. */
-#define HAVE_STRLCAT
+#define HAVE_STRLCAT 1
 
 /* Define to 1 if you have the `strlcpy' function. */
-#define HAVE_STRLCPY
+#define HAVE_STRLCPY 1
 
 /* Define to 1 if you have the `strncasecmp' function. */
-#define HAVE_STRNCASECMP
+#define HAVE_STRNCASECMP 1
 
 /* Define to 1 if you have the `strndup' function. */
-#define HAVE_STRNDUP
+#define HAVE_STRNDUP 1
 
 /* Support IPv6 for TCP connections */
-#define IPv6
+#define IPv6 1
 
 /* Support MIT-SHM Extension */
-#define MITSHM
+#define MITSHM 1
 
 /* Internal define for Xinerama */
-#define PANORAMIX
+#define PANORAMIX 1
 
 /* Support Present extension */
 #define PRESENT 1
@@ -84,10 +84,10 @@
 #define RENDER 1
 
 /* Support X resource extension */
-#define RES
+#define RES 1
 
 /* Support MIT-SCREEN-SAVER extension */
-#define SCREENSAVER
+#define SCREENSAVER 1
 
 /* Support SHAPE extension */
 #define SHAPE 1
@@ -105,19 +105,19 @@
 #define XCMISC 1
 
 /* Support Xdmcp */
-#define XDMCP
+#define XDMCP 1
 
 /* Build XFree86 BigFont extension */
-#define XF86BIGFONT
+#define XF86BIGFONT 1
 
 /* Support XFree86 Video Mode extension */
-#define XF86VIDMODE
+#define XF86VIDMODE 1
 
 /* Build XDGA support */
-#define XFreeXDGA
+#define XFreeXDGA 1
 
 /* Support Xinerama extension */
-#define XINERAMA
+#define XINERAMA 1
 
 /* Support X Input extension */
 #define XINPUT 1
@@ -132,10 +132,10 @@
 #undef DRI2
 
 /* Build Xorg server */
-#define XORGSERVER
+#define XORGSERVER 1
 
 /* Current Xorg version */
-#define XORG_VERSION_CURRENT 12012000
+#define XORG_VERSION_CURRENT 12101000
 
 /* Build Xv Extension */
 #undef XvExtension
@@ -165,7 +165,7 @@
 /* #undef _XOPEN_SOURCE */
 
 /* Vendor web address for support */
-#define __VENDORDWEBSUPPORT__ "http://x.cygwin.com/"
+#define __VENDORDWEBSUPPORT__ "https://x.cygwin.com/"
 
 /* Location of configuration file */
 #define XCONFIGFILE "xorg.conf"
@@ -198,7 +198,7 @@
 #undef XSERVER_LIBPCIACCESS
 
 /* X Access Control Extension */
-#define XACE
+#define XACE 1
 
 /* Have X server platform bus support */
 #undef XSERVER_PLATFORM_BUS
